using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Xml.Serialization;

namespace EQIA.EQIDL
{
    public partial class Page : Control
    {
        private string myTabText, myTabIcon, myTabIconActive;
        private List<string> myPieces;
        private RGB myTabTextColor, myTabTextActiveColor;

        [XmlElement("TabText", IsNullable = false)]
        [Browsable(true), Description("Text to attach to the tab that opens this page")]
        public string TabText { get { return myTabText; } set { myTabText = value; } }

        [XmlElement("TabTextColor", IsNullable = false)]
        [Browsable(true), Description("Text color for TabText.")]
        public RGB TabTextColor { get { return myTabTextColor; } set { myTabTextColor = value; } }

        [XmlElement("TabTextActiveColor", IsNullable = false)]
        [Browsable(true), Description("Text color for the active page.")]
        public RGB TabTextActiveColor { get { return myTabTextActiveColor; } set { myTabTextActiveColor = value; } }

        [XmlElement("TabIcon", IsNullable = false)]
        [Browsable(true), Description("Icon to attach to the tab that opens this page. The icon is always drawn left-justified. If any text also exists, it will be drawn to the right of the icon..")]
        public string TabIcon { get { return myTabIcon; } set { myTabIcon = value; } }

        [XmlElement("TabIconActive", IsNullable = false)]
        [Browsable(true), Description("Icon for the active page.")]
        public string TabIconActive { get { return myTabIconActive; } set { myTabIconActive = value; } }

        [XmlElement("Pieces", IsNullable = false)]
        [Browsable(true), Description("Children controls")]
        public List<string> Pieces { get { return myPieces; } set { myPieces = value; } }

        public Page() : this(null) { }
        public Page(EQInterface eqInterface) : base(eqInterface) { }

        protected override void SetProperties(object obj)
        {
            base.SetProperties(obj);

            Page temp_Page = obj as Page;
            if (temp_Page != null)
            {
                TabText = temp_Page.TabText;
                TabTextColor = temp_Page.TabTextColor;
                TabTextActiveColor = temp_Page.TabTextActiveColor;
                TabIcon = temp_Page.TabIcon;
                TabIconActive = temp_Page.TabIconActive;
                Pieces = temp_Page.Pieces;
            }
        }
    }
}
